@@ -23,11 +23,10 @@ impl Safe {
         name: Option<XorName>,
         type_tag: u64,
         private: bool,
-        dry_run: bool,
     ) -> Result<XorUrl> {
         let (xorname, op_batch) = self
             .safe_client
-            .create_register(name, type_tag, None, private, dry_run)
+            .create_register(name, type_tag, None, private, self.dry_run_mode)
             .await?;
 
         let scope = if private {
@@ -38,7 +37,7 @@ impl Safe {
         let xorurl =
             SafeUrl::encode_register(xorname, type_tag, scope, ContentType::Raw, self.xorurl_base)?;
 
-        if !dry_run {
+        if !self.dry_run_mode {
             self.safe_client.apply_register_ops(op_batch).await?;
         }
 
@@ -119,7 +118,6 @@ impl Safe {
         url: &str,
         entry: Entry,
         parents: BTreeSet<EntryHash>,
-        dry_run: bool,
     ) -> Result<EntryHash> {
         let reg_url = self.parse_and_resolve_url(url).await?;
         let address = self.get_register_address(&reg_url)?;
@@ -128,7 +126,7 @@ impl Safe {
             .write_to_register(address, entry, parents)
             .await?;
 
-        if !dry_run {
+        if !self.dry_run_mode {
             self.safe_client.apply_register_ops(op_batch).await?;
         }
 
@@ -159,8 +157,8 @@ mod tests {
     async fn test_register_create() -> Result<()> {
         let safe = new_safe_instance().await?;
 
-        let xorurl = safe.register_create(None, 25_000, false, false).await?;
-        let xorurl_priv = safe.register_create(None, 25_000, true, false).await?;
+        let xorurl = safe.register_create(None, 25_000, false).await?;
+        let xorurl_priv = safe.register_create(None, 25_000, true).await?;
 
         let received_data = safe.register_read(&xorurl).await?;
         let received_data_priv = safe.register_read(&xorurl_priv).await?;
@@ -170,15 +168,10 @@ mod tests {
 
         let initial_data = "initial data bytes".as_bytes().to_vec();
         let hash = safe
-            .register_write(&xorurl, initial_data.clone(), Default::default(), false)
+            .register_write(&xorurl, initial_data.clone(), Default::default())
             .await?;
         let hash_priv = safe
-            .register_write(
-                &xorurl_priv,
-                initial_data.clone(),
-                Default::default(),
-                false,
-            )
+            .register_write(&xorurl_priv, initial_data.clone(), Default::default())
             .await?;
 
         let received_entry = safe.register_read_entry(&xorurl, hash).await?;
